pub struct TargetBuilder<T>where
T: TargetBuilderState,{ /* private fields */ }Implementations
Sourceimpl TargetBuilder<TargetStartState>
impl TargetBuilder<TargetStartState>
Sourcepub fn new_normal_target(
target: NormalTarget<'_>,
schedule_role: &RoleRef,
) -> TargetBuilder<NormalTargetState>
pub fn new_normal_target( target: NormalTarget<'_>, schedule_role: &RoleRef, ) -> TargetBuilder<NormalTargetState>
Target that accepts any string input. This is all targets except Lambda, Step Functions, and EventBridge
Sourcepub fn new_json_target(
target: JsonTarget<'_>,
schedule_role: &RoleRef,
) -> TargetBuilder<JsonTargetState>
pub fn new_json_target( target: JsonTarget<'_>, schedule_role: &RoleRef, ) -> TargetBuilder<JsonTargetState>
Target that requires the input to be valid JSON
- Lambda
- Step Functions
- EventBridge
Sourceimpl<T> TargetBuilder<T>where
T: TargetBuilderState,
impl<T> TargetBuilder<T>where
T: TargetBuilderState,
pub fn retry_policy(self, retry_policy: RetryPolicy) -> TargetBuilder<T>
pub fn build(self) -> Target
Sourceimpl TargetBuilder<NormalTargetState>
impl TargetBuilder<NormalTargetState>
pub fn input(self, input: String) -> TargetBuilder<NormalTargetState>
Sourceimpl TargetBuilder<JsonTargetState>
impl TargetBuilder<JsonTargetState>
pub fn input(self, input: Value) -> TargetBuilder<JsonTargetState>