pub async fn diff(
name: StringWithOnlyAlphaNumericsAndHyphens,
stack: Stack,
) -> Result<String, String>Expand description
Creates a diff that will show what ids are being added / removed to an existing stack, as well as showing ids that remain without being added or removed. Currently, the diff does not show modifications to resources.
Parameters
name- The existing CloudFormation stack namestack- The new stackprint_progress- Print progress updates to standard out
AWS Credentials
This function requires valid AWS credentials. The AWS credentials must have permissions for:
cloudformation:DescribeStackscloudformation:GetTemplate