pub struct PermissionBuilder { /* private fields */ }Expand description
Builder for Lambda function permissions.
Creates permission resources that allow other AWS services to invoke a Lambda function. See https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lambda-permission.html
Implementations
Sourceimpl PermissionBuilder
impl PermissionBuilder
Sourcepub fn new<R>(
id: &str,
action: LambdaPermissionAction,
function_name: Value,
principal: R,
) -> PermissionBuilder
pub fn new<R>( id: &str, action: LambdaPermissionAction, function_name: Value, principal: R, ) -> PermissionBuilder
Creates a new permission builder for a Lambda function.
Arguments
id- Unique identifier for the permission resourceaction- Lambda action to allow (e.g., “lambda:InvokeFunction”)function_name- Reference to the Lambda functionprincipal- AWS service or account that will be granted permission
pub fn source_arn(self, arn: Value) -> PermissionBuilder
pub fn current_account(self) -> PermissionBuilder
pub fn build(self, stack_builder: &mut StackBuilder) -> PermissionRef