app_sync_api_name!() { /* proc-macro */ }Expand description
Creates a validated AppSyncApiName wrapper for AppSync Api names at compile time.
This macro ensures that the input string is a valid name for AppSync Apis, following AWS naming conventions and character restrictions.
Validation Rules
- String must not be empty
- Only alphanumeric characters, and the following special characters are allowed: _, - and whitespace
- Max length 50 characters