archive_policy!() { /* proc-macro */ }Expand description
Checks whether the value that will be wrapped in the ArchivePolicy struct is between 1 and 365
archive_policy!() { /* proc-macro */ }Checks whether the value that will be wrapped in the ArchivePolicy struct is between 1 and 365