delay_seconds!() { /* proc-macro */ }Expand description
Checks whether the value that will be wrapped in the DelaySeconds struct is between 0 and 900
delay_seconds!() { /* proc-macro */ }Checks whether the value that will be wrapped in the DelaySeconds struct is between 0 and 900