growth_factor!() { /* proc-macro */ }Expand description
Checks whether the value that will be wrapped in the GrowthFactor struct is between 0 and 100
growth_factor!() { /* proc-macro */ }Checks whether the value that will be wrapped in the GrowthFactor struct is between 0 and 100