max_flexible_time_window!() { /* proc-macro */ }Expand description
Checks whether the value that will be wrapped in the MaxFlexibleTimeWindow struct is between 1 and 1440
max_flexible_time_window!() { /* proc-macro */ }Checks whether the value that will be wrapped in the MaxFlexibleTimeWindow struct is between 1 and 1440