maximum_message_size!() { /* proc-macro */ }Expand description
Checks whether the value that will be wrapped in the MaximumMessageSize struct is between 1024 and 1048576
maximum_message_size!() { /* proc-macro */ }Checks whether the value that will be wrapped in the MaximumMessageSize struct is between 1024 and 1048576