memory!() { /* proc-macro */ }Expand description
Checks whether the value that will be wrapped in the Memory struct is between 128 and 10240
memory!() { /* proc-macro */ }Checks whether the value that will be wrapped in the Memory struct is between 128 and 10240