receive_message_wait_time!() { /* proc-macro */ }Expand description
Checks whether the value that will be wrapped in the ReceiveMessageWaitTime struct is between 0 and 20
receive_message_wait_time!() { /* proc-macro */ }Checks whether the value that will be wrapped in the ReceiveMessageWaitTime struct is between 0 and 20