ref_struct

Macro ref_struct 

macro_rules! ref_struct {
    ($name:ident) => { ... };
}
Generated a ref struct, which is used to reference a given resource when you need it as a dependency of some other resource. To allow the other resources to depend on this one, the ref struct has methods for retrieving the Ref, ARN, and other attributes.