s3_origin_read_timeout!() { /* proc-macro */ }Expand description
Checks whether the value that will be wrapped in the S3OriginReadTimeout struct is between 1 and 120
s3_origin_read_timeout!() { /* proc-macro */ }Checks whether the value that will be wrapped in the S3OriginReadTimeout struct is between 1 and 120