string_for_secret

Macro string_for_secret 

string_for_secret!() { /* proc-macro */ }
Creates a validated StringForSecret wrapper for AWS Secrets Manager secret names at compile time.

This macro ensures that the input string is a valid name for AWS Secrets Manager secrets, following AWS naming conventions and character restrictions.

Validation Rules

  • String must not be empty
  • Only alphanumeric characters, and the following special characters are allowed: /, _, +, =, ., @, -