success_feedback_sample_rate!() { /* proc-macro */ }Expand description
Checks whether the value that will be wrapped in the SuccessFeedbackSampleRate struct is between 0 and 100
success_feedback_sample_rate!() { /* proc-macro */ }Checks whether the value that will be wrapped in the SuccessFeedbackSampleRate struct is between 0 and 100