timeout!() { /* proc-macro */ }Expand description
Checks whether the value that will be wrapped in the Timeout struct is between 1 and 900
timeout!() { /* proc-macro */ }Checks whether the value that will be wrapped in the Timeout struct is between 1 and 900