visibility_timeout!() { /* proc-macro */ }Expand description
Checks whether the value that will be wrapped in the VisibilityTimeout struct is between 0 and 43200
visibility_timeout!() { /* proc-macro */ }Checks whether the value that will be wrapped in the VisibilityTimeout struct is between 0 and 43200