zip_file

Macro zip_file 

zip_file!() { /* proc-macro */ }
Creates a validated ZipFile wrapper for AWS Lambda deployment packages at compile time.

This macro ensures that the input string refers to a valid ZIP file that exists on the filesystem at compile time.

See the examples dir of this library for some usage examples

Validation Rules

  • Path must end with .zip extension
  • File must exist at compile time
  • Path must be valid Unicode
  • Both relative and absolute paths are allowed