BucketBuilder

Struct BucketBuilder 

pub struct BucketBuilder<T>{ /* private fields */ }
Builder for S3 buckets.

Provides configuration for S3 buckets including versioning, lifecycle rules, encryption, CORS, and static website hosting.

Example

use rusty_cdk_core::stack::StackBuilder;
use rusty_cdk_core::s3::{BucketBuilder, VersioningConfig, Encryption, VersioningConfiguration};
use rusty_cdk_core::wrappers::*;
use rusty_cdk_macros::bucket_name;

let mut stack_builder = StackBuilder::new();

// Create a simple bucket
let bucket = BucketBuilder::new("my-bucket")
    .name(bucket_name!("my-unique-bucket"))
    .versioning_configuration(VersioningConfiguration::Enabled)
    .encryption(Encryption::S3Managed)
    .build(&mut stack_builder);

// Create a website bucket
let (website_bucket, policy) = BucketBuilder::new("website-bucket")
    .website("index.html")
    .error_document("error.html")
    .build(&mut stack_builder);

See https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-s3-bucket.html

Implementations

Source

impl BucketBuilder<StartState>

pub fn new(id: &str) -> BucketBuilder<StartState>

Creates a new S3 bucket builder.

Arguments
  • id - Unique identifier for the bucket
pub fn build(self, stack_builder: &mut StackBuilder) -> BucketRef

Source

impl<T> BucketBuilder<T>

pub fn name(self, name: BucketName) -> BucketBuilder<T>

Sets the name of the bucket.

The bucket name must be globally unique.

pub fn abac_status(self, abac_status: AbacStatus) -> BucketBuilder<T>

Enables or disables attribute-based access control (ABAC) for the bucket.

pub fn acceleration_status( self, acceleration_status: AccelerationStatus, ) -> BucketBuilder<T>

Enables or disables S3 Transfer Acceleration for the bucket.

pub fn metadata_configuration( self, config: MetadataConfiguration, ) -> BucketBuilder<T>

Configures metadata for the bucket.

pub fn versioning_configuration( self, config: VersioningConfiguration, ) -> BucketBuilder<T>

Configures versioning for the bucket.

Once enabled, versioning cannot be disabled, only suspended.

pub fn lifecycle_configuration( self, config: LifecycleConfiguration, ) -> BucketBuilder<T>

Configures lifecycle rules for the bucket.

pub fn public_access_block_configuration( self, access: PublicAccessBlockConfiguration, ) -> BucketBuilder<T>

Configures the public access block for the bucket.

pub fn encryption(self, encryption: Encryption) -> BucketBuilder<T>

Configures server-side encryption for the bucket.

pub fn update_replace_and_deletion_policy( self, update_replace_policy: UpdateReplacePolicy, deletion_policy: DeletionPolicy, ) -> BucketBuilder<T>

Sets the update replace policy and deletion policy for the bucket

pub fn add_intelligent_tiering( self, tiering: IntelligentTieringConfiguration, ) -> BucketBuilder<T>

Adds an intelligent tiering configuration to the S3 bucket

pub fn add_notification( self, destination: NotificationDestination<'_>, ) -> BucketBuilder<T>

Adds a notification destination to the S3 bucket

pub fn website<I>(self, index_document: I) -> BucketBuilder<WebsiteState>
where I: Into<String>,

Configures the bucket for static website hosting.

Automatically disables public access blocks and creates a bucket policy allowing public GetObject access.

Source

impl BucketBuilder<WebsiteState>

pub fn error_document<I>(self, error: I) -> BucketBuilder<WebsiteState>
where I: Into<String>,

pub fn redirect_all<I>( self, hostname: I, protocol: Option<Protocol>, ) -> BucketBuilder<WebsiteState>
where I: Into<String>,

pub fn cors_config( self, config: CorsConfiguration, ) -> BucketBuilder<WebsiteState>

pub fn custom_bucket_policy_statements( self, statements: Vec<Statement>, ) -> BucketBuilder<WebsiteState>

Additional statements that will be added to the bucket policy.

The bucket policy will by default allow GETs from anywhere.

pub fn build( self, stack_builder: &mut StackBuilder, ) -> (BucketRef, BucketPolicyRef)

Builds the website bucket and adds it to the stack.

Returns both the bucket and the automatically created bucket policy that allows public read access.