pub enum DeletionPolicy {
Delete,
Snapshot,
Retain,
RetainExceptOnCreate,
}Expand description
Determines what happens with an existing resource when it is deleted
Variants
Delete
Delete deletes the resource (default)
Snapshot
Snapshot deletes it after creating a snapshot (if snapshots are possible)
Retain
Retain keeps the resource
RetainExceptOnCreate
RetainExceptOnCreate keeps the resource, except when it was just created during this stack operation