pub struct TopicPolicyBuilder { /* private fields */ }Implementations
Sourceimpl TopicPolicyBuilder
impl TopicPolicyBuilder
Sourcepub fn new(
id: &str,
doc: PolicyDocument,
topics: Vec<&TopicRef>,
) -> TopicPolicyBuilder
pub fn new( id: &str, doc: PolicyDocument, topics: Vec<&TopicRef>, ) -> TopicPolicyBuilder
Creates a new SNS topic policy builder.
Important Current limitation: CloudFormation only allows one resource policy for a given topic, applying the last one it receives. If you’ve added a bucket notification for this topic, which requires a policy, and you also define one yourself, one of both will get lost.
Arguments
id- Unique identifier for the topicdoc- The resource policy that should be applied to the topicstopics- Topics for which the policy is valid
pub fn build(self, stack_builder: &mut StackBuilder) -> TopicPolicyRef