pub struct QueuePolicyBuilder { /* private fields */ }Implementations
Sourceimpl QueuePolicyBuilder
impl QueuePolicyBuilder
Sourcepub fn new(
id: &str,
doc: PolicyDocument,
queues: Vec<&QueueRef>,
) -> QueuePolicyBuilder
pub fn new( id: &str, doc: PolicyDocument, queues: Vec<&QueueRef>, ) -> QueuePolicyBuilder
Creates a new SQS queue policy builder.
Important Current limitation: CloudFormation only allows one resource policy for a given queue, applying the last one it receives. If you’ve added a bucket notification for this queue, which requires a policy, and you also define one yourself, one of both will get lost.
Arguments
id- Unique identifier for the queuedoc- The resource policy that should be applied to the queuesqueues- Queues for which the policy is valid
pub fn build(self, stack_builder: &mut StackBuilder) -> QueuePolicyRef