pub struct BucketName(pub String);Expand description
A wrapper for creating new AWS S3 bucket names.
Validation Rules (when using the macro)
- Must contain only lowercase letters, numbers, periods (.), and hyphens (-)
- No uppercase letters are allowed
- Bucket name must be globally unique and available (verified at compile time by
bucket_name!) - Must be between 3 and 63 characters long
Recommended Usage
Use the bucket_name! macro from rusty-cdk-macros for compile-time validation
Note
The bucket_name! macro queries AWS at compile time to verify the bucket name is globally
available and caches the result for faster subsequent compilations.
Set RUSTY_CDK_NO_REMOTE=true to skip remote checks.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for BucketName
impl Clone for BucketName
Sourcefn clone(&self) -> BucketName
fn clone(&self) -> BucketName
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for BucketName
impl RefUnwindSafe for BucketName
impl Send for BucketName
impl Sync for BucketName
impl Unpin for BucketName
impl UnwindSafe for BucketName