TargetBuilder

Struct TargetBuilder 

pub struct TargetBuilder<T>{ /* private fields */ }

Implementations

Source

impl TargetBuilder<TargetStartState>

pub fn new_normal_target( target: NormalTarget<'_>, role_arn: Value, ) -> TargetBuilder<NormalTargetState>

Target that accepts any string input. This is all targets except Lambda, Step Functions, and EventBridge

pub fn new_json_target( target: JsonTarget<'_>, schedule_role: &RoleRef, ) -> TargetBuilder<JsonTargetState>

Target that requires the input to be valid JSON

  • Lambda
  • Step Functions
  • EventBridge
Source

impl<T> TargetBuilder<T>

pub fn retry_policy(self, retry_policy: RetryPolicy) -> TargetBuilder<T>

pub fn build(self) -> Target

Source

impl TargetBuilder<NormalTargetState>

Source

impl TargetBuilder<JsonTargetState>