diff

Function diff 

pub async fn diff(
    name: StringWithOnlyAlphaNumericsAndHyphens,
    stack: Stack,
) -> Result<String, String>
Creates a diff that will show what ids are being added / removed to an existing stack, as well as showing ids that remain without being added or removed. Currently, the diff does not show modifications to resources.

Parameters

  • name - The existing CloudFormation stack name
  • stack - The new stack
  • print_progress - Print progress updates to standard out

AWS Credentials

This function requires valid AWS credentials. The AWS credentials must have permissions for:

  • cloudformation:DescribeStacks
  • cloudformation:GetTemplate