macro_rules! type_state {
($state_trait:ident,$($structs:ident,)*) => { ... };
}Expand description
Pass in the trait name, followed by names for the state structs that should implement it Values separated by commas
macro_rules! type_state {
($state_trait:ident,$($structs:ident,)*) => { ... };
}Pass in the trait name, followed by names for the state structs that should implement it Values separated by commas