pub struct BucketBuilder<T>where
T: BucketBuilderState,{ /* private fields */ }Expand description
Builder for S3 buckets.
Provides configuration for S3 buckets including versioning, lifecycle rules, encryption, CORS, and static website hosting.
Example
ⓘ
use rusty_cdk_core::stack::StackBuilder;
use rusty_cdk_core::s3::{BucketBuilder, VersioningConfig, Encryption, VersioningConfiguration};
use rusty_cdk_core::wrappers::*;
use rusty_cdk_macros::bucket_name;
let mut stack_builder = StackBuilder::new();
// Create a simple bucket
let bucket = BucketBuilder::new("my-bucket")
.name(bucket_name!("my-unique-bucket"))
.versioning_configuration(VersioningConfiguration::Enabled)
.encryption(Encryption::S3Managed)
.build(&mut stack_builder);
// Create a website bucket
let (website_bucket, policy) = BucketBuilder::new("website-bucket")
.website("index.html")
.error_document("error.html")
.build(&mut stack_builder);Implementations
Sourceimpl BucketBuilder<StartState>
impl BucketBuilder<StartState>
Sourcepub fn new(id: &str) -> BucketBuilder<StartState>
pub fn new(id: &str) -> BucketBuilder<StartState>
pub fn build(self, stack_builder: &mut StackBuilder) -> BucketRef
Sourceimpl<T> BucketBuilder<T>where
T: BucketBuilderState,
impl<T> BucketBuilder<T>where
T: BucketBuilderState,
pub fn name(self, name: BucketName) -> BucketBuilder<T>
pub fn versioning_configuration( self, config: VersioningConfiguration, ) -> BucketBuilder<T>
pub fn lifecycle_configuration( self, config: LifecycleConfiguration, ) -> BucketBuilder<T>
pub fn public_access_block_configuration( self, access: PublicAccessBlockConfiguration, ) -> BucketBuilder<T>
pub fn encryption(self, encryption: Encryption) -> BucketBuilder<T>
Sourcepub fn website<I>(self, index_document: I) -> BucketBuilder<WebsiteState>
pub fn website<I>(self, index_document: I) -> BucketBuilder<WebsiteState>
Configures the bucket for static website hosting.
Automatically disables public access blocks and creates a bucket policy allowing public GetObject access.
Sourceimpl BucketBuilder<WebsiteState>
impl BucketBuilder<WebsiteState>
pub fn error_document<I>(self, error: I) -> BucketBuilder<WebsiteState>
pub fn redirect_all<I>( self, hostname: I, protocol: Option<Protocol>, ) -> BucketBuilder<WebsiteState>
pub fn cors_config( self, config: CorsConfiguration, ) -> BucketBuilder<WebsiteState>
Sourcepub fn build(
self,
stack_builder: &mut StackBuilder,
) -> (BucketRef, BucketPolicyRef)
pub fn build( self, stack_builder: &mut StackBuilder, ) -> (BucketRef, BucketPolicyRef)
Builds the website bucket and adds it to the stack.
Returns both the bucket and the automatically created bucket policy that allows public read access.