pub struct QueueBuilder<T>where
T: QueueBuilderState,{ /* private fields */ }Expand description
Builder for SQS queues.
Supports both standard and FIFO queues. FIFO queues have additional configuration options for deduplication and throughput.
Example
use rusty_cdk_core::stack::StackBuilder;
use rusty_cdk_core::sqs::QueueBuilder;
use rusty_cdk_core::wrappers::*;
use rusty_cdk_macros::{delay_seconds, message_retention_period, visibility_timeout};
let mut stack_builder = StackBuilder::new();
// Create a standard queue
let standard_queue = QueueBuilder::new("standard-queue")
.standard_queue()
.visibility_timeout(visibility_timeout!(60))
.build(&mut stack_builder);
// Create a FIFO queue
let queue = QueueBuilder::new("my-queue")
.fifo_queue()
.content_based_deduplication(true)
.delay_seconds(delay_seconds!(30))
.message_retention_period(message_retention_period!(600))
.build(&mut stack_builder);Implementations
Sourceimpl QueueBuilder<StartState>
impl QueueBuilder<StartState>
Sourcepub fn new(id: &str) -> QueueBuilder<StartState>
pub fn new(id: &str) -> QueueBuilder<StartState>
pub fn standard_queue(self) -> QueueBuilder<StandardState>
pub fn fifo_queue(self) -> QueueBuilder<FifoState>
Sourceimpl<T> QueueBuilder<T>where
T: QueueBuilderState,
impl<T> QueueBuilder<T>where
T: QueueBuilderState,
pub fn delay_seconds(self, delay: DelaySeconds) -> QueueBuilder<T>
pub fn maximum_message_size(self, size: MaximumMessageSize) -> QueueBuilder<T>
pub fn message_retention_period( self, period: MessageRetentionPeriod, ) -> QueueBuilder<T>
pub fn receive_message_wait_time_seconds( self, wait_time: ReceiveMessageWaitTime, ) -> QueueBuilder<T>
pub fn visibility_timeout(self, timeout: VisibilityTimeout) -> QueueBuilder<T>
pub fn sqs_managed_sse_enabled(self, enabled: bool) -> QueueBuilder<T>
pub fn dead_letter_queue<D>( self, dead_letter_target_arn: D, max_receive_count: NonZeroNumber, ) -> QueueBuilder<T>
pub fn redrive_allow_policy(self, policy: Value) -> QueueBuilder<T>
pub fn queue_name( self, name: StringWithOnlyAlphaNumericsAndUnderscores, ) -> QueueBuilder<T>
Sourceimpl QueueBuilder<StandardState>
impl QueueBuilder<StandardState>
pub fn build(self, stack_builder: &mut StackBuilder) -> QueueRef
Sourceimpl QueueBuilder<FifoState>
impl QueueBuilder<FifoState>
pub fn content_based_deduplication( self, enabled: bool, ) -> QueueBuilder<FifoState>
Sourcepub fn high_throughput_fifo(self) -> QueueBuilder<FifoState>
pub fn high_throughput_fifo(self) -> QueueBuilder<FifoState>
Enables high throughput mode for FIFO queues.
Sets deduplication scope to MessageGroup and throughput limit to PerMessageGroupId.
pub fn deduplication_scope( self, scope: DeduplicationScope, ) -> QueueBuilder<FifoState>
pub fn fifo_throughput_limit( self, limit: FifoThroughputLimit, ) -> QueueBuilder<FifoState>
Sourcepub fn build(self, stack_builder: &mut StackBuilder) -> QueueRef
pub fn build(self, stack_builder: &mut StackBuilder) -> QueueRef
Builds the FIFO queue and adds it to the stack.
Automatically appends the required “.fifo” suffix to the queue name if not already present.